summaryrefslogtreecommitdiffstats
path: root/debian/patches/0003-test_set_expire-increase-short-expiry-time-from-10s-.patch
blob: 35ba2f42b4c6eb87e9eee4e4802ac1dfc345ba4a (plain)
1
2
3
4
5
6
7
8
9
10
11
12
13
14
15
16
17
18
19
20
21
22
23
24
25
26
27
28
29
30
31
32
33
From: Andreas Stieger <Andreas.Stieger@gmx.de>
Date: Mon, 19 Jun 2023 23:21:43 +0200
Subject: test_set_expire: increase short expiry time from 10s to 60s

Fixes #2100, #2059

(cherry picked from commit 3be41e061e28ffe0bc368b6cce57c4e07a6d1983)
---
 src/tests/cli_tests.py | 6 +++---
 1 file changed, 3 insertions(+), 3 deletions(-)

diff --git a/src/tests/cli_tests.py b/src/tests/cli_tests.py
index e6f5ed7..f0bcc75 100755
--- a/src/tests/cli_tests.py
+++ b/src/tests/cli_tests.py
@@ -1997,14 +1997,14 @@ class Keystore(unittest.TestCase):
         matches = re.findall(r'(key expiration time: 63072000 seconds \(730 days\))', out)
         self.assertEqual(len(matches), 1)
 
-        # Expires in 10 seconds
-        ret, out, _ = run_proc(RNPK, ['--homedir', RNPDIR, '--edit-key', '--set-expire', '10', 'primary_with_empty_password@rnp'])
+        # Expires in 60 seconds
+        ret, out, _ = run_proc(RNPK, ['--homedir', RNPDIR, '--edit-key', '--set-expire', '60', 'primary_with_empty_password@rnp'])
         self.assertEqual(ret, 0)
         self.assertRegex(out, r'(?s)^.*\[EXPIRES .*')
 
         ret, out, _ = run_proc(RNP, ['--list-packets', kpath])
         self.assertEqual(ret, 0)
-        self.assertRegex(out, r'(?s)^.*key expiration time: 10 seconds \(0 days\).*')
+        self.assertRegex(out, r'(?s)^.*key expiration time: 60 seconds \(0 days\).*')
 
         # Expires in 10 hours
         ret, out, _ = run_proc(RNPK, ['--homedir', RNPDIR, '--edit-key', '--set-expire', '10h', 'primary_with_empty_password@rnp'])